@@ -1,4 +1,4 @@
-# This code is part of Perl distribution Mail-Transport version 3.008.
+# This code is part of Perl distribution Mail-Transport version 4.00.
 # The POD got stripped from this file by OODoc version 3.05.
 # For contributors see file ChangeLog.
 
@@ -10,27 +10,24 @@
 
 
 package Mail::Transport::Qmail;{
-our $VERSION = '3.008';
+our $VERSION = '4.00';
 }
 
-use base 'Mail::Transport::Send';
+use parent 'Mail::Transport::Send';
 
 use strict;
 use warnings;
 
-use Carp;
+use Log::Report   'mail-transport', import => [ qw/__x error fault/ ];
 
 #--------------------
 
 sub init($)
 {	my ($self, $args) = @_;
 	$args->{via} = 'qmail';
+	$self->SUPER::init($args);
 
-	$self->SUPER::init($args) or return;
-
-	$self->{MTM_program} = $args->{proxy} || $self->findBinary('qmail-inject', '/var/qmail/bin')
-		or return;
-
+	$self->{MTM_program} = $args->{proxy} || $self->findBinary('qmail-inject', '/var/qmail/bin') or return;
 	$self;
 }
 
@@ -42,17 +39,13 @@ sub trySend($@)
 	my $mailer;
 	if(open($mailer, '|-')==0)
 	{	{ exec $program; }
-		$self->log(NOTICE => "Errors when opening pipe to $program: $!");
-		exit 1;
+		fault __x"cannot open pipe to {program}.", program => $program;
 	}
 
 	$self->putContent($message, $mailer, undisclosed => 1);
 
-	unless($mailer->close)
-	{	$self->log(ERROR => "Errors when closing Qmail mailer $program: $!");
-		$? ||= $!;
-		return 0;
-	}
+	$mailer->close
+        or fault __x"errors when closing Qmail mailer {program}", program => $program;
 
 	1;
 }
